# -*- coding: utf-8 -*-
"""
Example 5 for acoular library

demonstrates different beamformers in frequency domain,
- persistence (loading of configured beamformers), see example 4 for 
  the first part (saving)

uses measured data in file 2008-05-16_11-36-00_468000.h5
calibration in file calib_06_05_2008.xml
microphone geometry in array_56.xml (part of acoular)


Copyright (c) 2006–2015 The Acoular developers.
All rights reserved.
"""

# imports from acoular
from acoular import L_p
# other imports
from pylab import figure, subplot, imshow, show, colorbar, title
from cPickle import load

#octave band of interest
cfreq = 4000

#===============================================================================
# load all beamformers in an external file
# important: import load from cPickle !!!
#===============================================================================
fi = open('all_bf.sav','r')
all_bf = load(fi)
fi.close()

#===============================================================================
# plot result maps for different beamformers in frequency domain
#===============================================================================
figure(1)
i1 = 1 #no of subplot
for b in all_bf:
    subplot(3,4,i1)
    i1 += 1
    g = b.grid
    map = b.synthetic(cfreq,1)[:,0,:]
    mx = L_p(map.max())
    imshow(L_p(map.T), vmax=mx, vmin=mx-15, 
           interpolation='nearest', extent=(g.x_min,g.x_max,g.z_min,g.z_max),
           origin='lower')
    colorbar()
    title(b.__class__.__name__+'\n '+b.steer, size=10)
show()




from acoular import *
from matplotlib import use
use('wx')
from pylab import *
from numpy import *
from os import path

ti = nidaq_import()
m = MicGeom(from_file=path.join( path.split(acoular.__file__)[0],'xml','array92x.xml'))
m.configure_traits()
ti.configure_traits()
ti.numsamples = int(ti.sample_freq/10.0)

nc = ti.numchannels
#~ nc = 64
if nc != m.num_mics:
    raise ValueError("Mikrofonanzahl passt nicht")
ti.get_single()

fig = figure()
#~ ax = fig.add_subplot(111)
#~ ax.set_title("Press 'a' to add stop")
# a single point
x = m.mpos[0]
y = m.mpos[1]
c = ones_like(x)*60.0
subplot(121)
sc = scatter(x,y,s=50,c=c, vmin=40, vmax=100)
axis('equal')
colorbar()
subplot(122)
pl0, = plot(c,ls='steps-mid',lw=2)
n = 10# zeitfenster fuer mittelung
mw = zeros((10,nc),'d')
cal = ones(nc,'d')*50
pl1, = plot(cal.copy(),ls='steps-mid',lw=2)
ylim(40,100)
last_calib = -1
            
def update(event):
    global last_calib
    d = ti.get_single()
    mw[1:]=mw[0:9]
    mw[0] = L_p(d.std(0))
    #~ mw[0] = random.rand(nc)*60+40
    data = mw.mean(0)
    st = mw.std(0)
    a = sc.get_array()
    sc.set_array(mw[0].copy())
    if st[data.argmax()]<1 and data.max()>90.0:
        dmax=data.argmax()
        if last_calib!=dmax:
            print dmax, data.max()
            cal[dmax]=data.max()
            pl1.set_ydata(cal.copy())
            last_calib=dmax
            savetxt('calib_helper.out',cal,'%f')
    else:
        last_calib=-1
        #~ pl1.draw()
    pl0.set_ydata(data)
    fig.canvas.draw()
    

import wx
id = wx.NewId()
actor = fig.canvas.manager.frame
timer = wx.Timer(actor, id=id)
timer.Start(200)
wx.EVT_TIMER(actor, id, update)

show()
print "ende"



# coding=UTF-8
#------------------------------------------------------------------------------
# Copyright (c) 2007-2015, Acoular Development Team.
#------------------------------------------------------------------------------

from setuptools import setup, Extension
from os.path import join, abspath, dirname
from os import remove
from shutil import copy
import sys

#import acoular.version as av
#bf_version = str(av.__version__)
#bf_author = str(av.__author__)

bf_version = "15.2.28"
bf_author = "Acoular developers"


# preparation for compiling the beamformer extension
import scipy.weave
weavepath = scipy.weave.__path__[0]
import numpy
numpypath = numpy.__path__[0]

extra_compile_args = ['-O3','-ffast-math','-msse3', \
        '-Wno-write-strings','-fopenmp']
extra_link_args = ['-lgomp']

# we use OpenMP for Linux only
if sys.platform[:5] == 'linux':
    compiler = 'unix'
else:    
    extra_compile_args.pop()
    extra_link_args.pop()

# provide weave_imp.cpp
copy(join(weavepath,'scxx','weave_imp.cpp'),'weave_imp.cpp')

# build C++ extension from weave-generated beamformer.cpp file
module1 = Extension('acoular.beamformer',
                    define_macros = [('MAJOR_VERSION', '15'),
                                     ('MINOR_VERSION', '1.31')],
                    include_dirs = [weavepath, join(weavepath,'scxx'), 
                                    join(weavepath,'blitz'),
                                    join(numpypath,'core','include')],
                    language = "c++",
#                    compiler = compiler,
                    extra_compile_args = extra_compile_args,
                    extra_link_args = extra_link_args,
                    sources = [
                        join('acoular','beamformer.cpp'),
                        'weave_imp.cpp'
                    ])

# Get the long description from the relevant file
here = abspath(dirname(__file__))
with open(join(here, 'README.rst')) as f:
    long_description = f.read()
                    
    
setup(name="acoular", 
      version=bf_version, 
      description="Library for acoustic beamforming",
      long_description=long_description,
      license="BSD",
      author=bf_author,
      author_email="info@acoular.org",
      url="http://www.acoular.org",
      classifiers=[
      'Development Status :: 5 - Production/Stable',
      'Intended Audience :: Education',
      'Intended Audience :: Science/Research',
      'Topic :: Scientific/Engineering :: Physics',
      'License :: OSI Approved :: BSD License',
      'Programming Language :: Python :: 2',
      'Programming Language :: Python :: 2.7',
      ],
      keywords='acoustic beamforming microphone array',
      packages = ['acoular'],
      install_requires = [
      'numpy>=1.8',
      'scipy>=0.13',
      'scikit-learn>=0.15',
      'pytables>=3.1',
      'traits>=4.4',
      'chaco>=4.4'],
#      setup_requires = [
#      'numpy>=1.8',
#      'scipy>=0.13',
#      'scikit-learn>=0.15',
#      'tables>=3.1',
#      'traits>=4.4',
#      'chaco>=4.4'],
      ext_modules = [module1],
      scripts=['ResultExplorer.py','CalibHelper.py'],
      include_package_data = True,
      package_data={'acoular': ['xml/*.xml']}
)

# cleanup
remove('weave_imp.cpp')